@@ -59,7 +59,7 @@ g_mime_stream_mem_get_type (void)
 			NULL, /* class_finalize */
 			NULL, /* class_data */
 			sizeof (GMimeStreamMem),
-			16,   /* n_preallocs */
+			0,    /* n_preallocs */
 			(GInstanceInitFunc) g_mime_stream_mem_init,
 		};
 		
@@ -263,7 +263,7 @@ stream_substream (GMimeStream *stream, off_t start, off_t end)
 {
 	GMimeStreamMem *mem;
 	
-	mem = g_object_new (GMIME_TYPE_STREAM_MEM, NULL, NULL);
+	mem = g_object_new (GMIME_TYPE_STREAM_MEM, NULL);
 	mem->owner = FALSE;
 	mem->buffer = GMIME_STREAM_MEM (stream)->buffer;
 	
@@ -285,7 +285,7 @@ g_mime_stream_mem_new (void)
 {
 	GMimeStreamMem *mem;
 	
-	mem = g_object_new (GMIME_TYPE_STREAM_MEM, NULL, NULL);
+	mem = g_object_new (GMIME_TYPE_STREAM_MEM, NULL);
 	mem->owner = TRUE;
 	mem->buffer = g_byte_array_new ();
 	
@@ -308,7 +308,7 @@ g_mime_stream_mem_new_with_byte_array (GByteArray *array)
 {
 	GMimeStreamMem *mem;
 	
-	mem = g_object_new (GMIME_TYPE_STREAM_MEM, NULL, NULL);
+	mem = g_object_new (GMIME_TYPE_STREAM_MEM, NULL);
 	mem->owner = TRUE;
 	mem->buffer = array;
 	
@@ -333,7 +333,7 @@ g_mime_stream_mem_new_with_buffer (const char *buffer, size_t len)
 {
 	GMimeStreamMem *mem;
 	
-	mem = g_object_new (GMIME_TYPE_STREAM_MEM, NULL, NULL);
+	mem = g_object_new (GMIME_TYPE_STREAM_MEM, NULL);
 	mem->owner = TRUE;
 	mem->buffer = g_byte_array_new ();
 	
@@ -380,7 +380,7 @@ g_mime_stream_mem_set_byte_array (GMimeStreamMem *mem, GByteArray *array)
 	g_return_if_fail (GMIME_IS_STREAM_MEM (mem));
 	g_return_if_fail (array != NULL);
 	
-	if (mem->buffer)
+	if (mem->owner && mem->buffer)
 		g_byte_array_free (mem->buffer, TRUE);
 	
 	mem->buffer = array;
