@@ -1,8 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/*
- *  Authors: Jeffrey Stedfast <fejj@ximian.com>
- *
- *  Copyright 2002-2004 Ximian, Inc. (www.ximian.com)
+/*  GMime
+ *  Copyright (C) 2000-2007 Jeffrey Stedfast
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,8 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
- *
+ *  Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 
@@ -34,7 +31,12 @@
 #include <fcntl.h>
 #include <errno.h>
 
+#ifdef HAVE_GETOPT_H
+#define _GNU_SOURCE
+#include <getopt.h>
+#else
 #include "getopt.h"
+#endif
 
 #include <gmime/gmime.h>
 
@@ -82,19 +84,18 @@ uufopen (const char *filename, const char *rw, int flags, mode_t mode)
 	return fdopen (fd, rw);
 }
 
-static void
+static int
 uudecode (const char *progname, int argc, char **argv)
 {
 	GMimeStream *istream, *ostream, *fstream;
-	register const unsigned char *p;
 	GMimeFilterBasicType encoding;
 	int fd, opt, longindex = 0;
-	unsigned char inbuf[4096];
-	const unsigned char *q;
+	register const char *p;
+	char inbuf[4096], *q;
 	GMimeFilter *filter;
+	GString *str = NULL;
 	const char *infile;
 	char *outfile;
-	GString *str;
 	mode_t mode;
 	FILE *fp;
 	
@@ -103,21 +104,21 @@ uudecode (const char *progname, int argc, char **argv)
 		switch (opt) {
 		case 'h':
 			usage (progname);
-			exit (0);
+			return 0;
 			break;
 		case 'v':
 			version (progname);
-			exit (0);
+			return 0;
 			break;
 		case 'o':
 			if (!(outfile = optarg)) {
 				usage (progname);
-				exit (1);
+				return -1;
 			}
 			break;
 		default:
 			printf ("Try `%s --help' for more information.\n", progname);
-			exit (1);
+			return -1;
 		}
 	}
 	
@@ -128,7 +129,7 @@ uudecode (const char *progname, int argc, char **argv)
 		if ((fp = uufopen (infile, "r", O_RDONLY, 0)) == NULL) {
 			fprintf (stderr, "%s: %s: uufopen %s\n", progname,
 				 infile, strerror (errno));
-			exit (1);
+			return -1;
 		}
 		
 		p = NULL;
@@ -151,14 +152,13 @@ uudecode (const char *progname, int argc, char **argv)
 		
 		if (p == NULL) {
 			fprintf (stderr, "%s: %s: No `begin' line\n", progname,
-				 infile == DEFAULT_FILENAME ? "stdin" : infile);
+				 (!strcmp (infile, DEFAULT_FILENAME)) ? "stdin" : infile);
 			fclose (fp);
-			str = NULL;
 			goto nexti;
 		}
 		
 		/* decode the mode */
-		if ((mode = strtoul (p, (char **) &q, 8) & 0777) && *q != ' ')
+		if ((mode = strtoul (p, &q, 8) & 0777) && *q != ' ')
 			goto nexti;
 		
 		while (*q == ' ')
@@ -195,7 +195,8 @@ uudecode (const char *progname, int argc, char **argv)
 				 outfile, strerror (errno));
 			g_string_free (str, TRUE);
 			fclose (fp);
-			exit (1);
+			
+			return -1;
 		}
 		
 		istream = g_mime_stream_file_new (fp);
@@ -215,7 +216,7 @@ uudecode (const char *progname, int argc, char **argv)
 			fprintf (stderr, "%s: %s: %s\n", progname, outfile, strerror (errno));
 			g_object_unref (fstream);
 			g_object_unref (istream);
-			exit (1);
+			return -1;
 		}
 		
 		g_mime_stream_flush (fstream);
@@ -223,11 +224,15 @@ uudecode (const char *progname, int argc, char **argv)
 		g_object_unref (istream);
 		
 	nexti:
-		if (str)
+		if (str) {
 			g_string_free (str, TRUE);
+			str = NULL;
+		}
 		
 		infile = argv[++optind];
 	} while (optind < argc);
+	
+	return 0;
 }
 
 int main (int argc, char **argv)
@@ -241,7 +246,8 @@ int main (int argc, char **argv)
 	else
 		progname++;
 	
-	uudecode (progname, argc, argv);
+	if (uudecode (progname, argc, argv) == -1)
+		return EXIT_FAILURE;
 	
-	return 0;
+	return EXIT_SUCCESS;
 }
